# Generated by Django 3.2.12 on 2022-03-16 17:24

from django.db import migrations, models
import django.db.models.deletion
import parler.fields
import parler.models
from parler.utils.context import switch_language


def create_privacy_levels(apps, schema_editor):
    PrivacyLevelLabel = apps.get_model('subjects', 'PrivacyLevelLabel')

    for value, label_en, label_de in [
        (1, 'increased', 'erhöht'),
        (2, 'high', 'hoch'),
    ]:
        level = PrivacyLevelLabel.objects.create(value=value)
        with switch_language(level, 'en'):
            level.label = label_en
        with switch_language(level, 'de'):
            level.label = label_de
        level.save()


def set_privacy_levels(apps, schema_editor):
    PrivacyLevelLabel = apps.get_model('subjects', 'PrivacyLevelLabel')
    Subject = apps.get_model('subjects', 'Subject')

    level = PrivacyLevelLabel.objects.get(value=1)
    Subject.objects.filter(privacy_level=1).update(privacy_level_label=level)

    level = PrivacyLevelLabel.objects.get(value=2)
    Subject.objects.filter(privacy_level=2).update(privacy_level_label=level)


class Migration(migrations.Migration):

    dependencies = [
        ('subjects', '0035_consent_underage_when_given'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrivacyLevelLabel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.PositiveIntegerField(choices=[(0, '0'), (1, '1'), (2, '2')], verbose_name='Value')),
            ],
            options={
                'ordering': ['value'],
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='PrivacyLevelLabelTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('label', models.CharField(max_length=64, verbose_name='Label')),
                ('master', parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='subjects.privacylevellabel')),
            ],
            options={
                'verbose_name': 'privacy level label Translation',
                'db_table': 'subjects_privacylevellabel_translation',
                'db_tablespace': '',
                'managed': True,
                'default_permissions': (),
                'unique_together': {('language_code', 'master')},
            },
            bases=(parler.models.TranslatedFieldsModelMixin, models.Model),
        ),
        migrations.RunPython(create_privacy_levels),

        migrations.AddField(
            model_name='subject',
            name='privacy_level_label',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='subjects.privacylevellabel', null=True),
        ),
        migrations.RunPython(set_privacy_levels),

        migrations.RemoveField(
            model_name='subject',
            name='privacy_level',
        ),
    ]
